package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`%0`!````A"0```````!``````````&@!`0``
M`````@```$``.``'`$``%@`5``8````%````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````(B>````````B)X`````````
M``$```````$````&````(/L````````@^P$``````"#[`0``````D`4`````
M``#X%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````(/L````````@^P$``````"#[`0``````X`0```````#@!`````````$`
M````````+VQI8B]L9"UM=7-L+7!O=V5R<&,V-&QE+G-O+C$````1````:```
M``(````'````FH4`"`E`!$E(CA1!BH0`Z`````!H````;````'````!Q````
M=@```'<```!X`````````'H``````````````'L```!\````?0``````````
M````:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E
M/RRR`8MOXD?&`;OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[7^IG)OAIP(*H^#[
M20```````````````````````````````````````````P`'`-@<````````
M`````````````````P`,`"#[`0````````````````"L`P```@`(`%A<````
M``````````````"Y`P```@`(`%1<``````````````````#&`P```@`(`%!<
M``````````````````#3`P```@`(`$Q<``````````````````#@`P```@`(
M`$1<``````````````````#M`P```@`(`+Q<``````````````````#Z`P``
M`@`(`,!<```````````````````'!````@`(`$A<```````````````````[
M!````@`(`&A<``````````````````!(!````@`(`&1<````````````````
M``!5!````@`(`%Q<``````````````````!B!````@`(`&!<````````````
M``````"6!````@`(`&Q<``````````````````"C!````@`(`'!<````````
M``````````"P!````@`(`*1<``````````````````"]!````@`(`(A<````
M``````````````#*!````@`(`(1<``````````````````#7!````@`(`)!<
M``````````````````#D!````@`(`(Q<``````````````````#Q!````@`(
M`(!<```````````````````B!0```@`(`)1<```````````````````Y!0``
M`@`(`)A<``````````````````!&!0```@`(`)Q<``````````````````!3
M!0```@`(`*!<``````````````````!M!0```@`(`'Q<````````````````
M``"@!0```@`(`$!<```````````````````,````$@``````````````````
M``````#3`0``$@`````````````````````````4````$0``````````````
M``````````#Y`0``$0````````````````````````!U`0``$@``````````
M```````````````;````$@````````````````````````"R`0``$@``````
M```````````````````C````$@`````````````````````````&`@``$@``
M``````````````````````"^`0``$@`````````````````````````J````
M(`````````````````````````!)`P``(0````````````````````````!"
M````$@````````````````````````!(````$@``````````````````````
M``!/````$@`````````````````````````6`P``$@``````````````````
M```````'`P``$@````````````````````````"+`@``$@``````````````
M``````````!6````$@`````````````````````````L`@``$@``````````
M``````````````!=````$@````````````````````````#``@``$@``````
M``````````````````!D````$@````````````````````````!L````(```
M``````````````````````"`````$@````````````````````````"I`@``
M$@````````````````````````"(````$@````````````````````````".
M````$@````````````````````````"7````(```````````````````````
M`````P``$@````````````````````````"S````$@``````````````````
M``````"X````$@`````````````````````````7`@``$0``````````````
M``````````#'`@``$@````````````````````````!9`@``$@``````````
M``````````````"_````$@````````````````````````!+`@``$@``````
M``````````````````"C`P``$@````````````````````````#2`@``$0``
M``````````````````````!(`P``$0````````````````````````!]`@``
M$@`````````````````````````U`P``$@````````````````````````!*
M`P``$0````````````````````````#&````$@``````````````````````
M```M`P``$@````````````````````````"#`0``$@``````````````````
M``````#/````(@````````````````````````#>````(```````````````
M``````````#T````$@````````````````````````#X`@``$@``````````
M``````````````!I`@``$@````````````````````````#Y````$@``````
M``````````````````#_````(`````````````````````````"T`@``$@``
M```````````````````````9`0``$@````````````````````````"C`0``
M$@`````````````````````````>`0``$@````````````````````````"9
M`@``$@````````````````````````"2`0``$@``````````````````````
M```D`0``$@`````````````````````````U`0``$@``````````````````
M```````G`@``$@````````````````````````")````$@``````````````
M```````````X`@``$@````````````````````````!R`@``$@``````````
M```````````````F`P``$@`````````````````````````[`0``$@``````
M```````````````````>`P``$@````````````````````````!/`0``$@``
M```````````````````````B`@``$@````````````````````````#A`0``
M$@````````````````````````!6`0``$@````````````````````````!=
M`0``$@````````````````````````!'`P``(0``````````````````````
M``!N`0``$@````````````````````````!"`P``$F`(`.0A````````H`(`
M``````#S`0``$F`)``1>````````$`````````"!!```$F`(`&A-````````
M%`H```````"M!0``$F`(`%Q;````````F``````````J!```$F`(`&Q%````
M````&`````````"0!```$F`'`-@<````````$``````````,!0``$F`(`'Q7
M````````X`,```````"3!0``$F`(`(1%````````+`(```````!9`P``$``3
M`+```@````````````````!O!```$F`(``Q,````````7`$```````".!```
M$F`(`*Q#````````9`````````#^!```$F`(`"A+````````C`````````!@
M!0``$@`(`+!'````````.`````````!E`P``$``3`!@1`@``````````````
M``"(`P``$F`(`+`D````````3`````````!Z!0``$F`(`.A'````````9`$`
M```````O!0``$0`2`*@``@``````"`````````!2`P``$``2`+```@``````
M``````````!>`P``$@`(`(0D``````````````````"1`P``$F`(`+1+````
M````6``````````4!```$F`(`(A$````````Y`````````"&!0``$F`(`$Q)
M````````W`$`````````;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L
M;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P
M:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!?2G9?4F5G:7-T97)#
M;&%S<V5S`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S=')L
M96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`
M4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UP<&,V
M-&QE+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I
M<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(O<&5R
M;#4O8V]R95]P97)L+T-/4D4`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`7W-A=F5G<'(P7S(U`%]S879E9W!R,%\R-`!?<V%V96=P<C!?
M,C,`7W-A=F5G<'(P7S(R`%]S879E9W!R,%\R,`!?<F5S=&=P<C!?,S``7W)E
M<W1G<'(P7S,Q`%]S879E9W!R,%\R,0!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!?<V%V96=P<C!?,CD`7W-A=F5G<'(P7S(X`%]S
M879E9W!R,%\R-@!?<V%V96=P<C!?,C<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`7W-A=F5G<'(P7S,P`%]S879E9W!R,%\S,0!?
M<F5S=&=P<C!?,CD`7W)E<W1G<'(P7S(R`%]R97-T9W!R,%\R,0!?<F5S=&=P
M<C!?,C0`7W)E<W1G<'(P7S(S`%]R97-T9W!R,%\R,`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!?<F5S=&=P<C!?,C4`;7E?<&%R7W!L
M`%]R97-T9W!R,%\R-@!?<F5S=&=P<C!?,C<`7W)E<W1G<'(P7S(X`'!A<E]B
M87-E;F%M90!?<F5S=&=P<C!?,3D`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV
M`'!A<E]F:6YD<')O9P!?<V%V96=P<C!?,3D`<&%R7V-L96%N=7``````````
M`````@``````%@````````````(``````!```@``````%@`````````C80``
M`````!@``@``````%@`````````980```````"```@``````%@`````````F
M80```````"@``@``````%@`````````<80```````#```@``````%@``````
M```A80```````#@``@``````%@`````````S80```````$@``@``````%@``
M```````480```````%```@``````%@````````!=7@```````&```@``````
M%@````````!27P```````&@``@``````%@````````!+7P```````'```@``
M````%@`````````(80```````'@``@``````%@````````!H7P```````(``
M`@``````%@`````````080```````)```@``````%@````````#Z8```````
M`)@``@``````%@````````#_8````````*@``@``````%@`````````^80``
M``````C_`0``````)@```#D``````````````!#_`0``````)@```%$`````
M`````````!C_`0``````)@```$L``````````````"#_`0``````)@```"<`
M`````````````"C_`0``````)@```$P``````````````##_`0``````)@``
M`#0``````````````#C_`0``````)@```$<``````````````$#_`0``````
M)@```#T``````````````$C_`0``````)@```%8``````````````%#_`0``
M````)@```!\``````````````%C_`0``````)@```%P``````````````&#_
M`0``````)@```%<``````````````&C_`0``````)@```"``````````````
M`'#_`0``````)@```$,``````````````!C]`0``````%0```!T`````````
M`````"#]`0``````%0```!X``````````````"C]`0``````%0```"$`````
M`````````##]`0``````%0```"(``````````````#C]`0``````%0```",`
M`````````````$#]`0``````%0```"0``````````````$C]`0``````%0``
M`"4``````````````%#]`0``````%0```"8``````````````%C]`0``````
M%0```"<``````````````&#]`0``````%0```"D``````````````&C]`0``
M````%0```"H``````````````'#]`0``````%0```"L``````````````'C]
M`0``````%0```"P``````````````(#]`0``````%0```"T`````````````
M`(C]`0``````%0```"X``````````````)#]`0``````%0```"\`````````
M`````)C]`0``````%0```#```````````````*#]`0``````%0```#$`````
M`````````*C]`0``````%0```#(``````````````+#]`0``````%0```#,`
M`````````````+C]`0``````%0```#4``````````````,#]`0``````%0``
M`#8``````````````,C]`0``````%0```#<``````````````-#]`0``````
M%0```#@``````````````-C]`0``````%0```#H``````````````.#]`0``
M````%0```#L``````````````.C]`0``````%0```#P``````````````/#]
M`0``````%0```#X``````````````/C]`0``````%0```#\`````````````
M``#^`0``````%0```$````````````````C^`0``````%0```$$`````````
M`````!#^`0``````%0```$(``````````````!C^`0``````%0```$4`````
M`````````"#^`0``````%0```$8``````````````"C^`0``````%0```$@`
M`````````````##^`0``````%0```$D``````````````#C^`0``````%0``
M`$H``````````````$#^`0``````%0```$L``````````````$C^`0``````
M%0```$P``````````````%#^`0``````%0```$T``````````````%C^`0``
M````%0```$X``````````````&#^`0``````%0```$\``````````````&C^
M`0``````%0```%```````````````'#^`0``````%0```%(`````````````
M`'C^`0``````%0```%,``````````````(#^`0``````%0```%0`````````
M`````(C^`0``````%0```%4``````````````)#^`0``````%0```%@`````
M`````````)C^`0``````%0```%D``````````````*#^`0``````%0```%H`
M`````````````*C^`0``````%0```%L``````````````+#^`0``````%0``
M`%T``````````````+C^`0``````%0```%X``````````````,#^`0``````
M%0```%\``````````````,C^`0``````%0```&```````````````-#^`0``
M````%0```&$``````````````-C^`0``````%0```&(``````````````.#^
M`0``````%0```&,``````````````.C^`0``````%0```&0`````````````
M`/#^`0``````%0```&4``````````````/C^`0``````%0```&<`````````
M``````(`3#PH8D(XI@((?!```?CA_R'XT0D`2````&`)/P!(````8"``(3@0
M``'HI@,(?"``@$X``````````````````````````!@`0?C__X(]>'Z,Z:8#
MB7T@!(!.&`!!^/__@CU8?XSII@.)?2`$@$X8`$'X__^"/=!_C.FF`XE](`2`
M3A@`0?C__X(]>'^,Z:8#B7T@!(!.&`!!^/__@CT(?XSII@.)?2`$@$X8`$'X
M__^"/3!^C.FF`XE](`2`3A@`0?C__X(]*'Z,Z:8#B7T@!(!.&`!!^/__@CU`
M?HSII@.)?2`$@$X8`$'X__^"/:!_C.FF`XE](`2`3A@`0?C__X(]N'Z,Z:8#
MB7T@!(!.&`!!^/__@CUP?XSII@.)?2`$@$X8`$'X__^"/0!_C.FF`XE](`2`
M3A@`0?C__X(]:'Z,Z:8#B7T@!(!.&`!!^/__@CV8?HSII@.)?2`$@$X8`$'X
M__^"/6A_C.FF`XE](`2`3A@`0?C__X(]2'Z,Z:8#B7T@!(!.&`!!^/__@CWX
M?HSII@.)?2`$@$X8`$'X__^"/:A_C.FF`XE](`2`3A@`0?C__X(].'Z,Z:8#
MB7T@!(!.&`!!^/__@CU0?HSII@.)?2`$@$X8`$'X__^"/4A_C.FF`XE](`2`
M3A@`0?C__X(]Z'^,Z:8#B7T@!(!.&`!!^/__@CW@?HSII@.)?2`$@$X8`$'X
M__^"/>A^C.FF`XE](`2`3A@`0?C__X(]$'^,Z:8#B7T@!(!.&`!!^/__@CT8
M?XSII@.)?2`$@$X8`$'X__^"/=!^C.FF`XE](`2`3A@`0?C__X(]D'^,Z:8#
MB7T@!(!.&`!!^/__@CW8?HSII@.)?2`$@$X8`$'X__^"/9!^C.FF`XE](`2`
M3A@`0?C__X(]R'Z,Z:8#B7T@!(!.&`!!^/__@CW(?XSII@.)?2`$@$X8`$'X
M__^"/8!_C.FF`XE](`2`3A@`0?C__X(]('Z,Z:8#B7T@!(!.&`!!^/__@CW`
M?XSII@.)?2`$@$X8`$'X__^"/?!^C.FF`XE](`2`3A@`0?C__X(]*'^,Z:8#
MB7T@!(!.&`!!^/__@CWP?XSII@.)?2`$@$X8`$'X__^"/4!_C.FF`XE](`2`
M3A@`0?C__X(]('^,Z:8#B7T@!(!.&`!!^/__@CTP?XSII@.)?2`$@$X8`$'X
M__^"/8!^C.FF`XE](`2`3A@`0?C__X(]^'^,Z:8#B7T@!(!.&`!!^/__@CV(
M?XSII@.)?2`$@$X8`$'X__^"/3A_C.FF`XE](`2`3A@`0?C__X(]B'Z,Z:8#
MB7T@!(!.&`!!^/__@CW@?XSII@.)?2`$@$X8`$'X__^"/;A_C.FF`XE](`2`
M3A@`0?C__X(]V'^,Z:8#B7T@!(!.&`!!^/__@CVH?HSII@.)?2`$@$X8`$'X
M__^"/5A^C.FF`XE](`2`3A@`0?C__X(]&'Z,Z:8#B7T@!(!.&`!!^/__@CV@
M?HSII@.)?2`$@$X8`$'X__^"/;!_C.FF`XE](`2`3A@`0?C__X(]P'Z,Z:8#
MB7T@!(!.&`!!^/__@CV8?XSII@.)?2`$@$X8`$'X__^"/6!_C.FF`XE](`2`
M3A@`0?C__X(]4'^,Z:8#B7T@!(!.&`!!^/__@CU@?HSII@.)?2`$@$X8`$'X
M__^"/;!^C.FF`XE](`2`3A@`0?C__X(]<'Z,Z:8#B7T@!(!.`@!,/!Q=0CBF
M`@A\\/_!^_C_X?L0``'X<?\A^'``@?AH`*'X<`"!.&@`H3A\`&&0?`!A.'G^
M_TL8`$'H````8%B`HN@```!@8(!BZ'@KI'PA_O]+&`!!Z````&!H@"+I````
M8$"`XNL``,F+``">+T``GD"%_?]+&`!!Z````&```*,O$))B^!``GD`!`&`X
M(?__2Q@`0>@E_?]+&`!!Z```?X!!_?]+&`!!Z'T*PYL``'^`,?W_2Q@`0>AZ
M!B.)`@`I87H&(YD``'^`&?W_2Q@`0>AZ!B.)`0`I87H&(YE\`&&`__\@.<``
M*7D%`&,XM`=C?$!(HW\<`)U`````8'"`@NC^_V(\H]]C.*W[_TL8`$'H)!]C
M>.WZ_TL8`$'H?@"AZ'``X>@```!@`0``.0"28O@```!@>!MF?```)^D``(4O
M```C^?[_(CWTX2DY"``C^0```&"H@2+I$``C^?[_(CWWX2DY&``C^00`(#GX
MD2*1__\E.2``*7D!`"DY"`"=00$`(#D!`"DL__\I.>``@D`$`"4Y``!`.0``
M`&`0DF+HM`<I?0,`I3@D'REY_O^"/!1*)GT``.`XM`>E?!#%A#CX_TGYK?W_
M2Q@`0>AY&W]\&`""0````&`0DF+HO?W_2Q@`0>AX&W]\````8!"28N@```!@
M\('".S7[_TL8`$'H_O]B//'?8SAA&@!(``"C+S@`GD````!@")(BZ0``J2\4
M`)Y`_O]B/*;?8S@]&@!(&!!^^````&`(DF+H``"C+P@`GD$Y-P!(````8!"2
M8NBI_/]+&`!!Z%GY_TL8`$'HD``A.'C[XW]L.`!("0"'Z`0`2#FT!TI]`0`(
M.20?2GFT!PA]%%)&??C_BOCX_O]+``````````&``@```@!,/'Q:0C@H`(R`
M%&*$?'@+(WSD!B%X````..'_`?BF`PA\$0``2,36`0`"`$P\4%I".*8""'P(
M`*,X_O_B/`3?YSC^_\(\V)W&.````#D0``'XX?\A^`(`@^C^_V(\Y*)C.$7[
M_TL8`$'H``````````&``````@!,/`1:0C@```!@````8+>!(CFP@6(X4$@C
M?0X`J2L@`)U,````8`B`(ND``*DO(`">3:8""'QX2RQ]I@,I?1```?CA_R'X
M&`!!^"$$@$X8`$'H(``A.!```>BF`PA\(`"`3@(`3#R@64(X````8````&"P
M@8(XL(%B.%`@@WQT'H1\=`Z$?)4!A'P@`()-````8!"`(ND``*DO(`">3:8"
M"'QX2RQ]I@,I?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF`PA\(`"`
M3@(`3#PT64(X````8+"!(HD``(DO(`">3*8""'P```!@&(`BZ?#_P?OX_^'[
M``"I+Q```?C1_R'X%`">00```&``@6+H"?K_2Q@`0>C__R(]___B/SA\*3DP
M?/\[4$C_?___0CUT'O]_,'Q*.?___SMX4UY]````8+B!(NE`2+]_/`"=0;7^
M_TL```!@((`BZ0``J2\4`)Y!_O]B/(0?8SB=^O]+&`!!Z`$`(#D```!@,``A
M.+"!(IDX-@!(`0`I.0```&"X@2+Y)!\I>2I(/GT8`$'XI@,I?7A++'TA!(!.
M&`!!Z)#__TL"`$P\3%A".*8""'P```!@*(`BZ0``J2\0``'XX?\A^!P`GD$`
M``!@_O]B/,"!@CB$'V,XR??_2Q@`0>C__R(]0'PI.7A+(WT``"/I``"I+R@`
MGD$```!@,(`BZ0``J2\8`)Y!I@,I?1@`0?AX2RQ](02`3A@`0>@@`"$X$``!
MZ*8#"'PP_O]+`@!,/,170CBF`@A\"`!`.:8#27TP`,,X_30`2`'](?CPCRWI
MJ`(A^0``(#DH``$Y"`!&.1``"#DL5"!]"0!&Z?#_*/D@PDEY(@!'>2X$*54@
M1DIY>%,I?2C`ZGAX4RE]'D+G5'@[*7WX_RCYQ/\`0D``(#D@``$YI@,I?7``
M*.E(`.CH&`!(Z7@Z*7UX4BE]"0!(Z7A2*7VD#RIYP@\I>7A+27T@`"EY@``H
M^=#_`$(```/H(`!CZ1``H^@8`(/H"`##Z#``X>O"+@EXI"X'>'A+YWPH`"'I
M@O#>>"``YWB"6O\_F7G_.V3P''B"6BD]%"+_?YEY*3D46BE]%$KG?'@BJ7PX
M,"E]>"(I?11*YWQD\,EX>/,I?2``ZG@@`#YY*"A)>7CRJ'R"\%UY.``(?7@J
M"'T4^@A]PBY?>7C[*7UX4-]_%$H(?8+P"7AX2YQ_(``;>2``G'LH\$IY..#G
M?'CK77UX.^=_.`#AZ\(N:7LXZ`I]@EK_/YEY_SL4*O]_%/KG?R@H9WMX2^=\
M>-B)?WA3*GU``"'I%#K_?R``^GO"+DA[>-"G?X):*3V9>2DY%/(I?8+P?GL4
M2BI]*"A*>WA#2GTH\&A[>/,>?112*7TX\.A_(``Y>7A#Z'Q(`.'H*/!?>\(N
M*GN"6N<\F7GG.!3BYWR"\%Q[>./\?Q0ZZ'PH*"A[..`_?7A3"'UXR,I_>/M?
M?5``0>D40N=\(`#[>,(N:7MXV(A_@EI*/9EY2CD4ZDI]@O`]>Q127WTH*'][
M>$O_?RCP*7MXZSU]%/I*?3CHZ7P@`%IY>$L)?5@``>G"+D=[>-"_?X):"#V9
M>0@Y%/((?8+P?GL40@E]*"A)>W@[*7TH\&=[>//^?!1*"'TX\$=](``9>7@[
MYW]@`.'K*/!*>\(N*7N"6O\_F7G_.Q3B_W^"\%Q[>.-<?13ZYW\H*"=[..`*
M?7A+YWQXR,E_>%,J?6@`(>D4.O]_(`#[>\(N:'MXV(=_@EHI/9EY*3D4ZBE]
M@O`]>Q1**GTH*&I[>$-*?2CP*'MXZQU]%%(I?3CHZ'\@`#IY>$/H?'``X>@H
M\'][PBY*>X):YSR9>><X%/+G?(+P?GMX\_Y_%#KH?"@H2'LX\#]]>%,(?7C0
MJG]X^U]]>`!!Z11"YWP@`/AX@O!;>\(N"7MXP,A_@EI*/9EY2CD4XDI]@O`<
M>Q127WTH*!][>$O_?RCP27MXVSM]%/I*?3C8Z7P@`%EY>$L)?8```>G"+B=[
M>,A_?X):"#V9>0@Y%.H(?11""7TH*"E[>#LI?2CP!WMXX_Q\%$H(?3C@1WT@
M`!IY>#OG?X@`X>LH\"I[PBY)>X):_S^9>?\[%/+_?X+P/GMX\UY]%/KG?R@H
M1WLX\`I]>$OG?'C0B7]X4RI]D``AZ10Z_W\@`/U[@O!9>\(NJ'MXZ,=_@EHI
M/9EY*3D4VBE]%$HJ?2@HJGMX0TI]*/!(>WC+&7T44BE].,CH?R``.'EX0^A\
MF`#AZ(+PNGLH\+U[PBX*>WC3NG^"\!M[@EKG/#C0/7V9>><X%.+G?!0ZZ'PH
M*`A[>%,(?7C`*G]XZUU]H`!!Z11"YWP@`/QXPBZ)>WC@2'^"6DH]F7E*.13R
M2GT44EU]*"B=>WA+O7\H\`E[>-L[?13J2GTXV.E\(`!>>7A+"7VH``'IPB['
M>WCP?7^"6@@]F7D(.13*"'V"\)E[*/"<>Q1""7UXRYE_*"C)>W@[*7TXR$=]
M>#NG?[``H>L42@A](``?>7CX*7_"+OQ[@EJ]/YEYO3L4TKU_@O#:>RCPWGL4
MZJ=_>-/:?R@HYWO(`,'K.-`*?7CCYWQX4RI]N``AZ10ZO7\@`+=[VF[>/\(N
MZ'IXN%Q_@EHI/:'KWCN9>2DY%-+>?Q3:*7T42BI]*"CJ>GA#2GUD\.A[@O#_
M>Q12*7UX^PA](``X>=``X>L@`!MYPBX*>SC8IW^"\/UZ>#N'?\``@>O:;O\_
MH>O_.Q3:_W^"6IP_F7F<.Q3*G'\4XH=_*"@'>WA3YWQD\.IZ>.M=?10ZG']X
MZ@I](`"9>WA*2GW"+BA[(`!*>2@H*7L4\DI]9/`>>X+P&'MX0RE]>,/>?Q1*
M2GUX\J=_(`!:>7CBYWS"+DA[*"A)>R``YWAX0RE]%/KG?-@``>D42N=\9/`I
M>X+P.7L@`+U[>,LY?=IN"#UXRLE_H>L(.7A2*GT@`/QX%.H(?2``2GG"+HE[
M%%((?2@HBGMD\%M[>$M*?8+P6GO@`"'I>--[?Q12"'T@`!UY>-HJ?W@Z1WTH
M**Q[PBZJ>]IN*3UX4XQ]Z`!!Z2``WGMD\)][H>LI.8+PG'L4\BE]>./_?R``
MYW@4.BE]VFY*/7CZ9W\48BE]\`"!Z2``.7MX0NA\H>M*.2``/GD4RDI](``(
M>63PO'N"\+U[>.N<?Q1"2GTH*,=[PB[(>WA#YWS:;HP]>.+H?Q0Z2GWX`.'H
M(`![>WA*"7VAZXPY(`!9>13:C'T@`"EY9/#=>X+PWGMX\[U_%$J,?2@H*'O"
M+BE[>$L(?=INYSQXZHE_%$*,?0`!`>D@`/][>%(J?:'KYS@@`)IY%/KG?"``
M2GD44N=\*"A)>\(N2GMD\#Y[@O`Y>WA3*7UXR]Y_%$KG?-IN"#UX\JE_(`#X
M>"``G'MX8BQ]H>L(.<(N"7L4X@A](`",>2@H"GMX2TI]%&((?0@!(>ED\%M[
M@O!:>WC3>W\44@A](``9>7C:RG]X.D=]*"@L>\(N*GO:;BD]>%.,?1`!0>D@
M`+U[9/`?>Z'K*3F"\!A[%.HI?7C#_W\@`.=X%#HI?=IN2CUX^F=_%&(I?1@!
M@>D@`-Y[>$+H?*'K2CD@`#IY%/)*?2``"'ED\#Q[@O`Y>WC+G'\40DI]*"A'
M>\(N2'MX0^=\VFZ,/7CBZ'\4.DI](`'AZ"``>WMX2@E]H>N,.2``6'D4VHQ]
M(``I>63P77N"\%I[>-.]?Q1*C'TH*`A[PBX)>WA+"'W:;N<\>.J)?Q1"C'TH
M`0'I(`#_>WA2*GVAZ^<X(`"9>13ZYWP@`$IY%%+G?"@H*7O"+BI[9/`>>X+P
M&'MX4RE]>,/>?Q1*YWS:;@@]>/*I?R``^G@@`)Q[>&(L?:'K"#G"+DE[%.((
M?2``C'DH*$I[>$M*?11B"'TP`2'I9/`[>X+P.7MXRWM_%%((?2``&'EXVLI_
M>#I'?2@H#'O"+@I[VFXI/7A3C'TX`4'I(`"]>V3P7WNAZRDY@O!:>Q3J*7UX
MT_]_(`#G>!0Z*7W:;DH]>/IG?Q1B*7U``8'I(`#>>WA"Z'RAZTHY(``Y>13R
M2GT@``AY9/`<>X+P&'MXPYQ_%$)*?2@H)WO"+BA[>$/G?-INC#UXXNA_%#I*
M?4@!X>@@`'M[>$H)?:'KC#D@`%IY%-J,?2``*7D42HQ]*"A(>\(N27MD\#U[
M@O`Y>WA+"'UXR[U_%$*,?5`!`>EXZHE_VF[G/"``FWD@`/][>%(J?:'KYSC"
M+FE[%/KG?"``2GDH*'][9/!>>X+P6GMXT]Y_%%+G?'A+_W_:;@@]%/KG?WCR
MJ7]8`>'H(`#W>R``G'MX8BQ]9/!Z>Z'K"#F"\'M[>-M:?\(NZ7H4X@A](`",
M>2@HZGH48@A]>$M*?=IN)SUXTL=_%%((?2``O7MX^N=\H>LI.2``&7D4ZBE]
M(`#G>!0Z*7TH*"I[PBXG>V3P^WIX.TI]@O#W>A12*7U@`4'I>+M[?WC:1W\@
M`-Y[>$+H?"``.'G:;DH](``(>:'K2CED\#Q[%/)*?8+P.7MXRYQ_%$)*?2@H
M!WO"+@A[>$/G?'CC:'\X2`A]..!I?Q0ZZGQX2PA]:`$AZ1N/0#T@`/]XW+Q*
M863P'7L@`$IY@O`8>Q1**GT@`%I[>,.]?Q3227\H*.Q[PB[I>R``"'EX2XQ]
M%-((?7CKB7\48HA].#@I?3CHB'\@`)EY>$,I?7`!`>ED\/Y[(`![>X+P_WMX
M^]Y_*"@G>Q1""GT@`"EY%-IH?\(N*'L4VBE]>$/G?'CSJ'\4.NE\.&`(?3CP
MJ7]X2PA]>`$AZ2``^GAD\#][(`"<>X+P.7LH*$Q[%$HJ?7C+_W\4XHE_(``(
M><(N27L4X@A]>$N,?7C[R7\48HA].#@I?3CXR'\@`)AY>$,I?8`!`>ED\%M[
M(`"]>X+P6GMXTWM_*"@'>Q1""GT@`"EY%.JH?\(N"'L4ZBE]>$/G?'C;Z'\4
M.NE\.&`(?3C8Z7]X2PA]B`$AZ2``^7AD\!Q[(`#>>X+P&'LH*"Q[%$HJ?7C#
MG'\4\LE_(``(><(N*7L4\@A]>$N,?7CC:7\48HA].#@I?3C@:'\@`)IY>$,I
M?9`!`>ED\#U[(`#_>X+P.7MXR[U_*"A'>Q1""GT@`"EY%/KH?\(N2'L4^BE]
M>$/G?'CKB'\4.NE\.&`(?3CHB7]X2PA]F`$AZ2``^'AD\%Y[(`![>X+P6GLH
M*`Q[%$HJ?7C3WG\4VFE_(``(><(N"7L4V@A]>$N,?7CSJ7\48HA].#@I?3CP
MJ'\@`)EY>$,I?:`!`>ED\!][(`"<>X+P&'MXP_]_*"@G>Q1""GT@`"EY%.*(
M?\(N*'L4XBE]>$/G?'C[R'\4.NE\.&`(?3CXR7]X2PA]J`$AZ2``^GAD\#M[
M(`"]>X+P.7LH*$Q[%$HJ?7C+>W\4ZJE_(``(><(N27L4Z@A]>$N,?7C;Z7\4
M8HA].#@I?3C8Z'\@`)AY>$,I?;`!`>ED\%Q[(`#>>X+P6GMXTYQ_*"@'>Q1"
M"GT@`"EY%/+(?\(N"'L4\BE]>$/G?'CC:'\4.NE\.&`(?3C@:7]X2PA]N`$A
MZ2``^7AD\!U[(`#_>X+P&'LH*"Q[%$HJ?7C#O7\4^NE_(``(><(N*7L4^@A]
M>$N,?7CKB7\48HA].#@I?3CHB'\@`)IY>$,I?<`!`>ED\#Y[(`![>X+P.7MX
MR]Y_*"A'>Q1""GT@`"EY%-IH?\(N2'L4VBE]>$/G?'CSJ'\4.NE\.&`(?3CP
MJ7]X2PA]R`$AZ2``^WAD\%][(`"<>X+P6GLH*&Q[%$HJ?7C3_W\4XHE_(``(
M><(N:7L4X@A]>$N,?7C[R7\48HA].#@I?3CXR'\@`)QY>$,I?=`!`>ED\'I[
M(`"]>X+P>WMXVUI_*"B'>Q1""GT@`"EY%.JH?\(NB'L4ZBE]>$/G?'C3Z'\4
M.NE\.&`(?3C0Z7]X2PA]V`$AZ2``_7AD\)M[(`#>>X+PG'LH**Q[%$HJ?7CC
M>W\4\LE_(``(><(NJ7L4\@A]>$N,?7C;27\48HA].#@I?3C82'\@`)YY>$,I
M?>`!`>ED\+Q[(`#_>X+PO7MXZYQ_*"C'>Q1""GT@`"EY%/KH?\(NR'L4^BE]
M>$/G?'CC:'\4.NE\.&`(?3C@:7]X2PA]Z`$AZ2``^'AD\-U[(`!:>X+PWGLH
M*`Q[%$HJ?7CSO7\4TDE_(``(><(N"7L4T@A]>$N,?7CKB7\48HA].#@I?3CH
MB'\@`)EY>$,I??`!`>ED\!Y[(`![>X+P&'MXP]Y_*"@G>Q1""GT@`"EY%-IH
M?\(N*'L4VBE]>$/G?'CSJ'\4.NE\.&`(?3CPJ7]X2PA]^`$AZ2``G'L@`/MX
M(``(><(N?WL@`+U[%$HJ?13BB7\H*&E[%.((?63P/'N"\#E[>/LI?7C+G'\4
M2@A]>./)?R``&GDX."E]..#'?W@[*7T``N'H"`+AZR``WGL@`"EY%#I*?<(N
M1WL4ZDI]%%))?2@H27MX.RE]%$I*?63P:7N"\'M[(`!7>7C;.WUBRB`]UL$I
M87C:AW\@`"EY>$+H?!3ZZ7\@``AY%/+_?\(NYWH40O]_*"CH>G@["'T0`N'H
M(`"<>Q1"_W]D\$A[@O!:>R``^7MXTQI]%#KI?'C2:'\4XN=\>%(*?<(N*'L@
M`$IY9/#]>A12YWPH*"I[>$-*?8+P]WH8`@'I>+N]?Q12YWP@`/AX>.I*?WCZ
M7WTH*`Q[PBX*>Q1""7UX4XQ](`![>R`"0>ED\#Y[@O`Y>WC+WG\4V@A](`#_
M>Q1227T4^@A]>/*_?Q1B"'T@`%I[*`*!Z7@ZYW\@`!QY%-)*?2``YWAD\!I[
M@O`8>WC#6G\4.DI]*"B?>\(NAWMX._]_>-+'?Q3Z2GT48HE],`+AZR``O7MX
M0NA\(`!9>13JC'T@``AY9/";>X+PG'L40HQ]>.-[?\(N*'LH*"=[%/KI?WA#
MYWQXVDA_%#J,?2``WGLX`N'H>%(*?2``EWD4\O]_(`!*>112_W\H*.AZPB[J
M>F3P/'N"\#E[>%,(?7C+G'\40O]_>.)J?R``^'L4.NE\(`!:>WAB3'W"+@A[
M%-+G?"``C'DH*`I[%&+G?'A#2GUD\/UZ0`(!Z8+P]WH44N=\>+N]?R``^7AX
MZHI_*"@L>WCZ7WW"+BI[>%.,?11""7U(`D'I(`![>V3P'GN"\!A[%-H(?7C#
MWG\@`/][%/H(?7CROW\48@A]%%))?5`"@>D@`)Q[>#KG?R``%WD4XDI](`#G
M>&3P.GN"\#E[%#I*?7C+6G_"+N=Z*"C_>A1BB7UX._]_>-+'?Q3Z2GT@`+U[
M6`+AZWA"Z'P@`%AY%.J,?2``"'ED\/MZ@O#W>GB[>W\40HQ]*"@'>\(N"'MX
M0^=\>-I(?Q0ZC'T4^NE_8`+AZ"``WGMX4@I](`"9>13R_W\@`$IY*"@H>Q12
M_W]D\!Q[PBXJ>X+P&'MXPYQ_>%,(?11"_W]XXFI_(`#W>Q0ZZ7P@`%I[>&),
M?<(NZ'H4TN=\(`",>2@HZGIX0TI]%&+G?&@"`>ED\#U[@O`Y>WC+O7\44N=\
M(`#X>'CJBG]X^E]]*"@,>\(N"GL40@E]>%.,?2``>WMP`D'I9/#^>H+P]WIX
MN]Y_%-H(?2``_WL44DE]%/H(?7CROW\48@A](`"<>W@"@>EX.N=_(``9>13B
M2GT@`.=X9/`:>X+P&'MXPUI_%#I*?2@H/WO"+B=[>#O_?WC2QW\4^DI]%&*)
M?8`"X>L@`+U[>$+H?"``5WD4ZHQ](``(>63P.WN"\#E[%$*,?7C+>W_"+NAZ
M*"CG>A3ZZ7]X0^=\>-I(?Q0ZC'T@`-Y[B`+AZ'A2"GT@`)AY%/+_?R``2GD4
M4O]_*"@(>\(N"GMD\/QZ>%,(?8+P]WH40O]_>+N<?R``^7MXXFI_PBXH>Q0Z
MZ7P@`%I[>&),?2@H*GL4TN=\>$-*?63P'7N0`@'I(`",>8+P&'MXP[U_%&+G
M?!12YWQXZHI_%$()?7CZ7WT@`'M[(`#Z>"``_WL4V@A]%/H(?<(N2GLH*%][
M9/`^>WA3_W^8`D'I@O`Y>WC+WG\@`)Q[%/KH?Q1:?GT44DE](`#H>Q3B2GUX
M\KQ_>#J'?\(N''D@`.=X(`"]>Q0Z2GTH*`=Y>./G?(+P''D4.DI]9/!'>X+P
M6GL@`$IY>-/Z?*`"X>@H\`AY>.,(?10BFGP4*JA\(`"$>!0Z*7UXTL=_>/K_
M?!3J*7T8`(/X(`#_>R@H1WD4^BE]PBY?>7C[YWP44D9]%#HI?2``2GD4`BE]
M(`"E>"``*7D@`&MY"`!#^1``H_@``"/Y(`!C^:@"0>GPCRWI>4I*?0``(#D,
M`()!J>+_2Q@`0>@``R$X)!\`2``````````!@`D```(`3#R(04(XI@((?-D>
M`$AY&WQ\L?\A^```P#L@`()!````8#B`(ND``,`[>..%?P``J>L``+TO'`">
M0%``(3AX\\-_W!X`2#T`B2L4`)Y!`0"E.```)8D``*DO[/^>0%`HO'QX(YI\
MM`>_?'CKNW\``-OK``"^+\3_GD%X^^5_>..$?WCSPW_5W_]+&`!!Z```HR\H
M`)Y`KO@^?3T`B2\<`)Y`4-B]?P$`_SMT'KU_%/K>?P``NI.$__]+"`![.[#_
M_TL``````````8`&```"`$P\N$!".*8""'P0``'XD?\A^&0`@3CPCRWI:``A
M^0``(#D5__]+:`!!Z?"/+>EY2DI]```@.0P`@D&!X?]+&`!!Z'``(3@0``'H
MI@,(?"``@$X``````````8`````"`$P\6$!".*8""'SP_\'[^/_A^W@;?WP0
M``'X@?\A^/"/+>EH`"'Y```@.60`P3MX\\1_>/OC?Z'^_TL``*,O(`">0&@`
M(>GPCTWI>5(I?0``0#D\`()!!>'_2Q@`0>AF`"'I````8#B``NDD'REY^/])
M.0``*.D44BE]$`!)Z0``JB\)`$GY]/^>0*3__TN``"$X@!T`2``````````!
M@`(```(`3#RT/T(XI@((?`$=`$A1_R'X>!M]?/"/+>EH`"'Y```@.0``)(D]
M`"EI-``I?7[9*5442N1_>/OC?SW?_TL8`$'H9`"!.'@;?'QXZZ-_Y?W_2WD;
M?GQ,`()!'=__2Q@`0>A`&+Q_]`"=0?___SO__]X[`0`_C0``J2\!`#Z=]/^>
M0```8#AH`$'I\(\MZ7E*2GT``"`Y<`&"01W@_TL8`$'H````8#B`8NL``,`[
M``!;Z_C_6CD)`"KI``"I+T``GD````!@\($B@0(`GC@``(DO.`">0;0'A'QX
MTT-_)!^$>%7=_TL8`$'H``"C+P``>_A0`)Y`__]@.(S__TL!`-X[M`?>?[#_
M_TL!`"`Y````8+0'A'PD'X-X\($BD8G@_TL8`$'H>1MY?,S_@D$D'\5[>--$
M?SGA_TL8`$'H```[^P$`/CD``%OI````.20?*7DJ20I]9`#!DWCKHW\``".)
M``"I+X``GD!F`,'K````8#B`8NM0&'U\`@"<.[0'8WP4XF-\``!;ZQW@_TL8
M`$'H)!_>>P``HR\J\7I\6/^>068`(>D``%OI__^].R0?*7DJ2"I]`0!=C0``
MJB\``$F9-`">0#T`0#G___\[``!)F0$`7XT``*HO`0!)G?3_GD"@_O]+/0")
M*X#_GD$!`&,X;/__2ST`BBO,_YY!`0`I.;3__TNP`"$X/!L`2``````````!
M@`<```(`3#R8/4(XI@((?.$:`$C!_B'X>1M]?/"/+>GX`"'Y```@.6@`@D$`
M`#V)``")+UP`GD&!W_]+&`!!Z'D;?'Q,`()!_O]B/_[_0C_^_R(_7=][.US?
M6CM?WSD[:``!.WCC@W]5V_]+&`!!Z'D;?WPX`()`>..#?TG=_TL8`$'H>.NC
M?Y'>_TL8`$'H^`!!Z?"/+>EY2DI]```@.=0`@D']W?]+&`!!Z!,`_SMXVV1_
M>/OC?[7?_TL8`$'H``"C+Z#_GD%XTT1_>/OC?YW?_TL8`$'H``"C+XC_GD%X
MZZ-_?=S_2Q@`0>AX&WY\>/OC?VW<_TL8`$'H%/)C?`(`8SBT!V-\B=[_2Q@`
M0>AX^^9_>.NE?WC+)']X&WY\"=W_2Q@`0>AXPP1_>//#?^';_TL8`$'H__^#
M+WCSPW\H`)Y!@``A@28$*54`0(DO&`">0+G^_TMX\\-_`=O_2Q@`0>@`__]+
M9=[_2Q@`0>CH__]+0`$A.+09`$@``````````8`(```"`$P\%#Q".*8""'SP
M_\'[^/_A^W@;?GP```!@0(#BZQ```?C1_R'X``!_@+'<_TL8`$'H^`&#.'CS
MPW]1W/]+&`!!Z```HR\0`)Y!``!@.#``(3A\&0!(``!_@('<_TL8`$'H$`(C
M@28$*54`0(DO(`">0`(`@#AX\\-_1=K_2Q@`0>@T`&-\?MEC5,3__TL``'^`
M2=S_2Q@`0>@0`B.!)@0I5?__*FT`H(HOH/^>0,3__TL``````````8`"```"
M`$P\5#M".*8""'P```!@0(`BZ1```?CA_R'X``!I@/W;_TL8`$'H````8$B`
MHNC^_\(\_O^"/##?QCAEWX0X6=W_2Q@`0>@@`"$X$``!Z*8#"'P@`(!.````
M``````&``````@!,//`Z0CBF`@A\^/_A^P```&!`@.+K$``!^-'_(?@``'^`
ME=O_2Q@`0>AY__]+``!_@(7;_TL8`$'H_O_B//[_HCSSX><X_O^"/````#EX
M.^9\?-BE.('?A#CAV?]+&`!!Z#``(3A(&`!(``````````&``0```@!,/'@Z
M0CBF`@A\U1<`2&'?(?CPCRWI>"`A^0``(#EIV?]+&`!!Z&@`X3O^_\(\_O^"
M/'@;97R6W\8XFM^$.'C[XW_!VO]+&`!!Z```@R\H`)Q```#`.W@@0>GPCRWI
M>4I*?0``(#EX\\-_9`""00W;_TL8`$'H<!"A.WC[XW\`$*`X>.ND?^':_TL8
M`$'HM`=_?```GR^\_YQ!`0!_.+0'8WS)V_]+&`!!Z'D;?GRH_X)!>/OE?WCK
MI'\%V/]+&`!!Z```(#FN^3Y]C/__2Z`@(3A(%P!(``````````&``P```@!,
M/)0Y0C@<__]+`````````````````@!,/'PY0CBF`@A\)H"0?0@`@9&Q%@!(
M,>\A^'@;?GS^_V(\IM]C.'@CGWSPCRWI:!`A^0``(#F5^/]++P"`.'@;>GQX
M\\-_,=C_2Q@`0>@``*,O-`">0?[_8CQX\\1_K]]C.&WY_TMH$"'I\(]-Z7E2
M*7T``$`Y>//#?Y0!@D$!VO]+&`!!Z'CSPW_^_X(_L=C_2Q@`0>B\WYP[_O\B
M/WCCA'_^_^(^M`=[?'C[XW^9VO]+&`!!Z/[_PCX``*`Z```Z+EW?.3MX&W]\
M````.P$`>SN^W_<ZGN#6.F@`H3L`@+5B``"_+W#_GD$``#^)``")+P@`GD!X
MRS]_(`"207C[Y']XTT-_1=O_2Q@`0>AXXX1_``"C+^@`GD%X^^-_(=C_2Q@`
M0>BT!V-\%!H_??__*8DO`(DOL`">010:>WS_#X,O%/^=07C[Y7]X\\=_>+OF
M?GBSQ'YXZZ-_K=C_2Q@`0>@```!@0(#BZP``?X#5V/]+&`!!Z/@!@SAXZZ-_
M<=?_2Q@`0>@``*,O;`">0```?X"QV/]+&`!!Z!`"(X$F!"E5`*B)?U``GD`!
M`(`X>.NC?W76_TL8`$'H``"C+S@`GD#^_V(\>.ND?Z_?8S@!^/]+>.NC?_77
M_TL8`$'H>!M^?(3^_TO__V,XM`=C?*X9'W\X__]+>..$?P``8#A)V?]+&`!!
MZ'@;?WS8_O]+T!`A.`@`@8$@@9!]Y!0`2``````````#@`L``/__0SD!`"J)
M`0`*.0``J2\(`)Y`(`"`3B\`B2L(`)Y``@!J.'A#"GW<__]+````````````
M`````@!,/!@W0CBF`@A\^/_A^WD;?WSP_\'[$``!^-'_(?@0`()!``#?BP``
MOB\<`)Y`_O]B/%W?8S@QU_]+&`!!Z#``(3B0%`!(E=;_2Q@`0>C__R,Y%$J_
M?'@;:7P4&G]\__]C.$`8OW\,`)U!__^_+P@`GD`!`"`Y`0`I+/__*3FL`()!
M``!%B2\`BB^(`)Y!__]%.5`H/WU`4+]_"`"=0`$`(#D``$6)+P"*+W``GD#_
M_T4Y4"@_?4!0OW\,`)U!__^_+P@`GD`!`"`Y`0`I+/__I3C__RDY<`""0%`H
MOWP``&`X`@`E.0`0J2M4_YU!````8`$`I3CX@<([>/OD?WCSPW]5U_]+&`!!
MZ'CSPW\P__]+__^E.&#__TL!`"DL__^E./__*3E\_X)`0"B_?X#_GD`O`)XK
M^/Z>0?[_8CR^WV,X]/[_2P``18DO`(HO?/^>08C__TL``````````8`"```"
M`$P\M#5".*8""'S^_T(],-]*.?[_8CS`WV,X_1(`2%'_(?C^_\(__O^B/^'?
MWCNFW[T[_O_B/_[_@C_]W_\[!^"<._"/+>F(`"'Y```@.0H`*CD``,GH"`#I
MZ!``">D8`$GI(``IH6``P?AH`.'X<``!^7@`0?F``"&QZ?3_2_[_8CS)WV,X
MW?3_2_[_8CS1WV,XT?3_2_[_8CS:WV,XQ?3_2WCSPW^]]/]+_O]B//'?8SBQ
M]/]+>.NC?ZGT_TMX^^-_H?3_2WCC@W^9]/]+_O]B/!'@8SB-]/]+_O]B/*_?
M8SB!]/]+_O]B/!O@8SAU]/]+_O]B/"3@8SAI]/]+_O]B/"_@8SC]\_]+>1MD
M?`P`@D%XXX-_\?3_2_[_8CQ`X&,XX?/_2WD;9'P0`()!_O]B/%+@8SC1]/]+
M_O]B/%W@8SC!\_]+>1MD?#@`@D%XZZ-_M?3_2_[_@CQX\\-_B>"$.*7T_TN(
M`$'I\(\MZ7E*2GT``"`Y4`""03W5_TL8`$'H_O]B/&W@8SAY\_]+>1MD?`P`
M@D%X^^-_N/__2_[_@CP*`*`X?N"$.'$`83C9TO]+&`!!Z```HR^<_YY`>P"!
M.-3__TNP`"$XB!$`2``````````!@`0```(`3#S8,T(X````8`B!(H'__XDO
M8`">0*8""'S^_V(\_=]C.!```?BA_R'X_?+_2P``0#D``",L'`""00``(XD`
M`*DO$`">03``*6G__TDQ$$E*?6``(3@```!@$``!Z`B!0I$```!@I@,(?`J!
M8N@@`(!.````8`J!8N@@`(!.``````````&``````@!,/$PS0CBF`@A\$``!
M^.'_(?BAU/]+&`!!Z#'3_TL8`$'H```C+!P`@D$``"/I(``A.'A+(WT0``'H
MI@,(?"``@$X``"`YZ/__2P`````````!@`````(`3#ST,D(XI@((?````&`8
M@0+I````8""!0ND```!@*($BZ0```&`0@>+H'1``2"'_(?C^_R(__O\"/W@;
M?GP``*`[O-\Y.Y[@&#OPC\WHF`#!^```P#AH``'Y<`!!^6``03MX`"'Y````
M8#"!`ND```!@.(%"Z0```&!`@2+I8`#A^(```?F(`$'YD``A^2K0_7\``+\O
M(`">0)@`X>CPCRWI>4KG?```(#F<`()!2=/_2Q@`0>AX^^-_B?'_2WCSQ']Y
M&WQ\$`""00``/(D``(DO%`">0'C[XW]M\O]+"`"].ZS__TOYT?]+&`!!Z```
MHR_L_YY`>//#?[W1_TL8`$'H>!M[?'CC@W^MT?]+&`!!Z!0:>WP"`&,XS=/_
M2Q@`0>AXPP1_>..'?WC+)G]X\\5_>!M[?$G2_TL8`$'H>-MD?Y3__TO@`"$X
M.`\`2``````````!@`@```(`3#R8,4(XI@((?````&!(@0+I````8%"!0ND`
M``!@6($BZ;4.`$C__P`\_O]"/_!]`&"FWUH[>!MX?'C30W]J`2%\H('A.P$`
MP3SPC^WHF('F^```X#@```!@8('BZ-!^'_G8?E_Y````8&B!`ND```!@<(%"
MZ>!^/_D```!@>($BZ0!___@(?Q_Y$']?^1A_/_D```!@@(%"Z0```&"(@2+I
M````8)"!`ND@?U_Y*'\_^0```&"8@4+I````8*"!(NGH?A_Y\'Y?^?A^/_D9
M\/]+>1M^?$@`@D$``#Z)``")+SP`GD'%_?]+>//#?_G0_TL8`$'H>!M\?`$`
MP3QXXX-_F('FZ/"/S>AY,N=\``#`..P(@D&%T?]+&`!!Z#7]_TMY&WY\U`&"
M07CSPW_^_V(_*=#_2Q@`0>C__]X[DN![.Z0/8W@!`&,X0=+_2Q@`0>AX&WQ\
M>!M]?`$`OHP``*4OI`&>0```P#L`?W\[*MB^?P``O2\\`)Y!>.NC?VGO_TMY
M&WU\F`&"00``/8D``(DOC`&>0?7S_TL``*,O@`&>07CKHW]!T/]+&`!!Z'@;
M?7P``&`[T'X_.P``O2\<`)Y`*LC;?P``OB\0`)Y!```^B0``B2]0`9Y`>.NC
M?_[_(C]YS_]+&`!!Z+[?.3MX&WY\>..#?V7/_TL8`$'H%/+#?P0$WCNT!]Y_
M>//#?WW1_TL8`$'H_O_B//[_@CQXXXA_E^#G.'C+)G]XZZ5_G."$.'@;>WSM
MS_]+&`!!Z,`!@#AXVV-_O='_2Q@`0>C__X,O_`">0'W/_TL8`$'H```C@1$`
MB2_H`)Y!````8%"`(ND``/CK```IZ6@`(?E5S_]+&`!!Z/[_@CQXVV9_>/OE
M?Z7@A#@"`./H:`!AZ"W-_TL8`$'H``"`.U#^_TLY[O]+``#`.WD;:7P<`()!
M```IB0``B2\0`)Y!'<__2Q@`0>AX&WY\``"^+P@`O3M,_IY`*N!]?```HR_$
M_YY`_O_"/XO@WCLT_O]+``"@.^A^GSO@__]+>.NC?WC;9'\5S_]+&`!!Z`(`
MO3M`_O]+"`#>.TS^_TMX\\-_8?+_2P``HR\4`)Y!>//#?ZW._TL8`$'H>!M]
M?`@`>SMP_O]+````8$"`@NL``'R`!<__2Q@`0>CX`8,X>-MC?Z7._TL8`$'H
M>1M]?&`&@D```'R`X<[_2Q@`0>@0`B.!)@0I50!`B2]$!IY```!\@,7._TL8
M`$'H%`+C@EG/_TL8`$'H`+B#?R0&GD```'R`I<[_2Q@`0>@0`B.!_@4I5<`!
MB2\(!IY`>//#?[7/_TL8`$'H>!M\?/[_8CP<XF,X_>S_2P``HR\D`)Y!``#8
MZ^W-_TL8`$'H>!MD?'CSPW\9]/]+>1MW?`@`@D```/CJ>+OC?CW-_TL8`$'H
MM`=^?`,`GB^(`)U`_/]^./[_@CS@X(0X%!IW?"70_TL8`$'H``"C+V@`GD`$
M`)XO'`">0?S_WCNT!]Y_%/+7?___/HDO`(DO2`">0`@`V.L``+XO/`">07CS
MPW_9S/]+&`!!Z`,`HRLH`)U`_/]C./[_@CSEX(0X%!I^?,7/_TL8`$'H``"C
M+P@`GD!X\]=_$?G_2P``HR]D!)Y```"`.'B[XWZES/]+&`!!Z'D;>'Q,!()!
M`@"@..[_@#A=S_]+&`!!Z/A_WSL&`*`X>//$?WC#`W_YRO]+&`!!Z/A_/XD`
M`(DOM`">0/E_/XE#`(DOJ`">0/I_/XE!`(DOG`">0/M_/XE#`(DOD`">0/Q_
M/XE(`(DOA`">0/U_/XE%`(DO>`">0`(`H#C&_X`X>,,#?^G._TL8`$'H*0"@
M.'CSQ']XPP-_B<K_2Q@`0>C^_P(]>//'?_/A"#G^_X(\>,LF?WC;97_JX(0X
M>..#?Y',_TL8`$'H>-MC?[G*_TL8`$'H>..$?WC30W\][/]+>..#?_7X_TM`
M^_]+``"@.```@#AXPP-___^@.G'._TL8`$'H16<@/?A_WSH!(REA(`2U5C!_
MGSIH?W\Z,'\_^<WO(#V)JREA(``I>3A_/_FZF"`]_MPI82``*7E`?S_Y,A`@
M/794*6%(?S_YTL,@/?#A*6$@`"EY4'\_^0``(#E8?S_Y8'\_^:A_/Y%XJZ5^
M>+/$?GC#`W^IR?]+&`!!Z+0'?7P``)TOI`&=07C#`W]H?Q\[:<K_2Q@`0>A8
M?]_K@/]`.6!_O^NB[L5[M`>I?`$`I3@X`(4OM`>C?*Y)6'T4&GA\?`*=0$``
MI2```(`XM`>E?#!__SI1R_]+&`!!Z'B[XWXET_]+.`"@.```@#AXPP-_-<O_
M2Q@`0>@"1JE[,']_.*-_OYNG?]^;_O\"/[!__SJ@?S^9`H2I>Y+@&#NA?S^9
M`L*I>\A_OSNB?S^9`D;)>Z1_/YD"A,E[I7\_F0+"R7L``,`[IG\_F;W2_TLP
M?S_I`D8J>;-_/YFP?U^9`H0J>;%_7YD"PBIY.'\_Z;)_7YD"1BIYMW\_F;1_
M7YD"A"IYM7]?F0+"*GE`?S_IMG]?F0)&*GF[?S^9N']?F0*$*GFY?U^9`L(J
M>4A_/^FZ?U^9`D8J>;]_/YF\?U^9`H0J>;U_7YD"PBIY4'\_Z;Y_7YD"1BIY
MPW\_F<!_7YD"A"IYP7]?F0+"*GG"?U^9KO"W?*0/PWMXPP1_%!I]?`$`WCM-
MRO]+&`!!Z!0`OBO@_YY````@.?[_`CWSX0@Y>.NG?_!_/YF$_?]+6']?Z20?
MJ7L44BE](``I>4!(JG\0`)U`8']?Z0$`2CE@?U_YJG]_Z&!_7^E8?S_Y0A^I
M>P``HR\42BI]8'\_^5P`GD%``",A>.NW?P!(G7\(`)U`>$LW?;0'_GYXL\1^
M>//%?Q0:<WQYQ_]+&`!!Z*A_/X$4NBE]0`")+ZA_/Y'`_9Y`4.BW?Q3RUG^T
M![U_>*.#?DG1_TL(``!(^'_?.S\`G2\@`)U!>.NE?WCSQ']XFV-^+<?_2Q@`
M0>BH?[^3@/W_2P``_N@(`![I$`!>Z1@`/NG`_[T[0`#>.[0'O7]H?__X<'\?
M^>#__NCH_Q[I>']?^8!_/_GP_U[I^/\^Z8A___B0?Q_YF']?^:!_/_F`__]+
M.`"E(```@#BT!Z5\J/W_2_[_@CS^_V(\B>"$./W?8SBYZ/]+_O_B/_[_PC_S
MX?\[!^'>.V''_TL8`$'H_O^"/'C[Z']XRR9_>-ME?W@;9WSYX(0X>..#?[G(
M_TL8`$'HP`&`.'CC@W^)RO]+&`!!Z/__@R\4_)Y`2<C_2Q@`0>@``".!$0")
M+P#\GD`)Q_]+&`!!Z`$`O3MX^^E_M`>]?WC+)G]X&V=\>.NH?WC;97]X\\1_
M>..#?UG(_TL8`$'HH/__2P```&!0@"+I``"XZ/[_@CQXVV9_&.&$.```:>C9
MQ?]+&`!!Z*SX_TL``"'H$`4`2``````````!@`T```(`3#R$)T(XI@((?,T$
M`$AA_R'X````8$"`XNL``'^`+<C_2Q@`0>AX&WY\``!_@!W(_TL8`$'HL``C
MB?[_8CSAWV,XL0`^F8WF_TL``",L'`""00``(XDQ`(DO$`">0`$`(XD``(DO
M"`">06WQ_TL``'^`````8/"!PCO1Q_]+&`!!Z/[_@CP+`,`X`0"@.&OAA#A1
MQO]+&`!!Z```(RR4`()```!_@*7'_TL8`$'H_O^"/`,`P#@!`*`X<.&$."7&
M_TL8`$'H>1M]?&@!@D```'^`><?_2Q@`0>C^_X(\`P#`.`$`H#@MX(0X^<7_
M2Q@`0>AY&WU\S`&"0?[_8CROWV,XT>7_2WD;?'R``8)!``!_@#G'_TL8`$'H
M$``]Z7CCA7\``(GHS<3_2Q@`0>B4`0!($``CZ2```#\``*`[``088R@`2>L(
M$#Z!`0"=.[0'FW\`X(E_+`"=0```?X#MQO]+&`!!Z```P#AXZZ5_>--$?[7'
M_TL8`$'H>1MY?$P`@D````!@^)$B@?__*3D`Z(E_$/^>0`$`H#L($#Z!`.B)
M?P#_G4```'^``0"].[0'O7^9QO]+&`!!Z'C31']YQO]+&`!!Z-3__TL0$#[I
M``!9Z20?>WLJV&E_#``J@3A("7\`!(DO)`">0!``BNAXVV-_8<C_2Q@`0>@`
M`*,OA/^>0+0'G7]`__]+``!_@#W&_TL8`$'H``"9Z`(`P#@``*`X&<?_2Q@`
M0>AX&V1\P/__2P``?X`5QO]+&`!!Z!``/>G^_Z(\<N&E.```B>BEP_]+&`!!
MZ!``/>D``"GI#``I@4``*G5H_H)!``!_@-W%_TL8`$'H$``]Z0``B>@IQ/]+
M&`!!Z$C^_TN)ZO]+>1M\?```?X#0`()!L<7_2Q@`0>@0`#WI>..%?P``B>A%
MP_]+&`!!Z'CC@W^)P_]+&`!!Z```?X"%Q?]+&`!!Z'@;?7P``'^`=<7_2Q@`
M0>C^_X(\`0"@.'?AA#@AQ/]+&`!!Z/[_HCR,X:4X>!MD?'CKHW_QPO]+&`!!
MZ```?X`]Q?]+&`!!Z```(#FQ`".9_O]B/*;?8SBMX_]+````8```HR\(DF+X
M3`">0````&``DF+HL?+_2P```&```*,O"))B^#``GD#^_V(\DN%C.,'#_TL8
M`$'HY<3_2Q@`0>@```!@`))"Z1``/>D``*KHI/W_2P```&`(DF+HP`&`.&'&
M_TL8`$'H$0"#+W@;9GPL`)Y!`0`C.0$`B2L@`)U`$!`^Z1@0ONC^_V(\L^%C
M.```B>A=P_]+&`!!Z*``(3A$`0!(``````````&`"````@!,/*0C0CBF`@A\
M\/_!^_C_X?MX&WY\$``!^)'_(?AU[/]+,>S_2W@;?WRI[_]+``"C+U``GD$`
M`+XO2`">00``/HD``(DO/`">0?[_@CQX^^-_E^"$.#G#_TL8`$'H`!B_?R``
MGD!P`"$X>//#?Q```>CP_\'K^/_AZZ8#"'R4Y?]+<``A.-@``$@`````````
M`8`"```"`$P\#"-".*8""'SX_^'[___B/RA\_SL0``'XT?\A^/G_/^G__ZDO
M#`">0#``(3B<``!(I@,I?1@`0?AX2RQ](02`3A@`0>C8__]+F/]A^J#_@?JH
M_Z'ZL/_!^KC_X?K`_P'[R/\A^]#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q``
M`?@@`(!.F/]AZJ#_@>JH_Z'JL/_!ZKC_X>K`_P'KR/\AZ]#_0>O8_V'KX/^!
MZQ```>CH_Z'KI@,(?/#_P>OX_^'K(`"`3O#_P>L0``'H^/_AZZ8#"'P@`(!.
M**`!``````"F`@A\!0"?0J8":'WP_TOHI@,(?%!@BWT46F)]T/\,.```B^F"
M\`!XI@.)?0@`:^D@!(!.````8,C__TO$__]+P/__2[S__TNX__]+M/__2[#_
M_TNL__]+J/__2Z3__TN@__]+G/__2YC__TN4__]+D/__2XS__TN(__]+A/__
M2X#__TM\__]+>/__2W3__TMP__]+;/__2VC__TMD__]+8/__2US__TM8__]+
M5/__2U#__TM,__]+2/__2T3__TM`__]+//__2SC__TLT__]+,/__2RS__TLH
M__]+)/__2R#__TL<__]+&/__2Q3__TL0__]+#/__2PC__TL$__]+`/__2_S^
M_TOX_O]+]/[_2_#^_TOL_O]+Z/[_2^3^_TO@_O]+W/[_2]C^_TL"`$P\_"!"
M.*8""'P0``'XX?\A^+W'_TL```!@(``A.!```>BF`PA\(`"`3G!E<FQX<VDN
M8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```+BX`)7,O)7,`
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O
M`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(
M10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`4UE35$5-`"4P,G@`<&%R+0`E<R5S
M)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`)7,Z('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@
M<F5T<GD@>6]U<B!O<&5R871I;VXI"@!!4D=6`!@`<&5R;`!005(Z.E!A8VME
M<CHZ5D524TE/3@`Q+C`S-@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C
M=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`%5315(`55-%4DY!344`
M5$5-4$1)4@!435``+W1M<`!,24)0051(`$193$1?3$E"4D%265]0051(`%-(
M3$E"7U!!5$@`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@
M*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U
M,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE
M(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R
M(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D
M;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D
M;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA
M<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E
M="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D
M:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F
M9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E
M="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0[
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M
M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@
M)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^
M>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M
M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE
M;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E
M=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA
M;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\[
M"FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM
M(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@
M(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN
M+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,
M12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R
M:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H
M95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N
M86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[
M7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@
M(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F
M:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S
M+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?
M0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M
M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T
M96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO
M<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET
M92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N
M=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=6
M7S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[
M4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?
M8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH````4``````````%Z4@`$>$$!&PP!```````4````'````,1^___$
M!``````````````4````-````&2^__\L`0```$$)00!$!D$`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/__________``````````#_
M_________P`````````````````````!``````````$``````````0``````
M``#A`@````````\`````````:@,````````,`````````-@<````````#0``
M```````$7@```````/7^_V\`````Z`$````````%`````````'@.````````
M!@````````"H`@````````H`````````N04````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<`````````(!<```````````!P````
M`/!<`````````P``<`````````````````<`````````.!0````````(````
M`````.@"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````1````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P`````C80```````!EA````
M````)F$````````<80```````"%A````````,V$``````````````````!1A
M````````75X``````````````````%)?````````2U\````````(80``````
M`&A?````````$&$``````````````````/I@````````_V``````````````
M`````#YA````````1T-#.B`H06QP:6YE(#8N,RXP*2`V+C,N,```+G-H<W1R
M=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD
M>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R
M86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````R`$```````#(`0```````!X````````````````````!````````
M````````````$P```/;__V\"`````````.@!````````Z`$```````"\````
M``````,`````````"````````````````````!T````+`````@````````"H
M`@```````*@"````````T`L````````$````'0````@`````````&```````
M```E`````P````(`````````>`X```````!X#@```````+D%````````````
M```````!````````````````````+0````0````"`````````#@4````````
M.!0```````#H`@````````,`````````"``````````8`````````#<````$
M````0@`````````@%P```````"`7````````N`4````````#````$`````@`
M````````&`````````!!`````0````8`````````V!P```````#8'```````
M`#0````````````````````$````````````````````1P````$````&````
M`````"`=````````(!T```````#D0```````````````````(```````````
M`````````$T````!````!@`````````$7@````````1>````````+```````
M``````````````0```````````````````!3`````0````(`````````,%X`
M```````P7@````````I````````````````````(````````````````````
M6P````$````"`````````#R>````````/)X```````!,````````````````
M````!````````````````````&4````!`````P`````````@^P$``````"#[
M````````$`````````````````````@```````````````````!L`````0``
M``,`````````,/L!```````P^P```````!`````````````````````(````
M````````````````<P````$````#`````````$#[`0``````0/L````````(
M````````````````````"````````````````````'@````&`````P``````
M``!(^P$``````$C[````````P`$````````$``````````@`````````$```
M```````\````"`````,`````````"/T!```````(_0```````/@!````````
M```````````(``````````@`````````@0````$````#``````````#_`0``
M`````/\```````!X``````````````````````$````````(`````````(8`
M```!`````P````````````(``````````0``````L```````````````````
M``@```````````````````",````"`````,`````````L``"``````"P``$`
M`````&@0```````````````````(````````````````````D0````$````P
M````````````````````L``!```````:`````````````````````0``````
M```!``````````$````#`````````````````````````,H``0``````F@``
=``````````````````$`````````````````````
